Pybricks end-user API & Documentation
=====================================

This repository documents the Pybricks end-user MicroPython API.

Each `Pybricks firmware`_ comes with the `Pybricks package`_. All modules,
classes, methods, and functions in that package have optimized implementations
in C for high performance and reduced memory footprint.

This repository provides an empty, pure Python blueprint of that package. It is
used to generate the `official documentation`_.
See the `contributor's guide <CONTRIBUTING.md>`_ for acceptable changes and
instructions to build the documentation locally.

For general discussion, please visit the `support`_ issue tracker.

.. _Pybricks package: pybricks
.. _Pybricks firmware: https://github.com/pybricks/pybricks-micropython
.. _official documentation: https://docs.pybricks.com/
.. _support: https://github.com/pybricks/support/issues
